@@ -58,6 +58,7 @@ class InputKeys(BaseModel):
     country_code: Optional[str] = Field(alias="countryCode", default=None)
     date_to_analyze: Optional[str] = Field(alias="dateToAnalyze", default=None)
     authorization_reference: Optional[str] = Field(alias="authorizationReference", default=None)
+    passport_number: Optional[str] = Field(alias="passportNumber", default=None)
 
     class Config:
         populate_by_name = True
@@ -287,7 +288,7 @@ class RequestAsyncModule:
             )
             raise_for_status_improved(r)
             sync_data_response = r.json()
-            return AsyncRequestSync(
+            return AsyncRequestAsync(
                 base_url=self.altscore_client._altdata_base_url,
                 header_builder=self.build_headers,
                 renew_token=self.renew_token,
