@@ -1,7 +1,8 @@
 from altscore.borrower_central.model.borrower import BorrowersAsyncModule, BorrowersSyncModule
 from altscore.borrower_central.model.data_models import DataModelAsyncModule, DataModelSyncModule
 from altscore.borrower_central.model.executions import ExecutionAsyncModule, ExecutionSyncModule
-from altscore.borrower_central.model.tools import ReportGeneratorAsyncModule, ReportGeneratorSyncModule
+from altscore.borrower_central.model.tools import ReportGeneratorAsyncModule, ReportGeneratorSyncModule, \
+    CommunicationsAsyncModule, CommunicationsSyncModule
 from altscore.borrower_central.model.form_templates import FormTemplatesAsyncModule, FormTemplatesSyncModule
 from altscore.borrower_central.model.otp_templates import OTPTemplatesAsyncModule, OTPTemplatesSyncModule
 from altscore.borrower_central.model.addresses import AddressesAsyncModule, AddressesSyncModule
@@ -20,6 +21,7 @@ from altscore.borrower_central.model.forms import FormsAsyncModule, FormsSyncMod
 from altscore.borrower_central.model.policy_alerts import AlertsAsyncModule, AlertsSyncModule
 from altscore.borrower_central.model.policy_rules import RulesAsyncModule, RulesSyncModule
 from altscore.borrower_central.model.integrations.sat import SatIntegrationAsyncModule, SatIntegrationSyncModule
+from altscore.borrower_central.model.integrations.sri import SriIntegrationAsyncModule, SriIntegrationSyncModule
 from altscore.borrower_central.model.automations import AutomationsAsyncModule, AutomationsSyncModule
 from altscore.borrower_central.model.stages import StagesAsyncModule, StagesSyncModule
 from altscore.borrower_central.model.risk_ratings import RiskRatingsAsyncModule, RiskRatingsSyncModule
@@ -31,10 +33,19 @@ from altscore.borrower_central.model.steps import StepsAsyncModule, StepsSyncMod
 from altscore.borrower_central.model.list_of_similar import ListOfSimilarAsyncModule, ListOfSimilarSyncModule
 from altscore.borrower_central.model.execution_batches import ExecutionBatchAsyncModule, ExecutionBatchSyncModule
 from altscore.borrower_central.model.cms_settings import CMSSettingsAsyncModule, CMSSettingsSyncModule
-
+from altscore.borrower_central.model.conversational_channel_connectors import ChannelConnectorAsyncModule, \
+    ChannelConnectorSyncModule
+from altscore.borrower_central.model.conversational_conversations import ConversationAsyncModule, ConversationSyncModule
+from altscore.borrower_central.model.conversational_messages import MessageAsyncModule, MessageSyncModule
+from altscore.borrower_central.model.custom_reports import CustomReportsSyncModule, CustomReportsAsyncModule
+from altscore.borrower_central.model.report_templates import ReportTemplateSyncModule, \
+    ReportTemplateSyncModule
+from altscore.borrower_central.model.deals import DealsAsyncModule, DealsSyncModule
+from altscore.borrower_central.model.deal_fields import DealFieldsAsyncModule, DealFieldsSyncModule
+from altscore.borrower_central.model.deal_steps import DealStepsAsyncModule, DealStepsSyncModule
+from altscore.borrower_central.model.deal_contacts import DealContactsAsyncModule, DealContactsSyncModule
 
 class BorrowerCentralAsync:
-
     def __init__(self, altscore_client):
         self.addresses = AddressesAsyncModule(altscore_client)
         self.authorizations = AuthorizationsAsyncModule(altscore_client)
@@ -63,16 +74,26 @@ class BorrowerCentralAsync:
         self.rules = RulesAsyncModule(altscore_client)
         self.policies = PolicyAsyncModule(altscore_client)
         self.sat_integration = SatIntegrationAsyncModule(altscore_client)
+        self.sri_integration = SriIntegrationAsyncModule(altscore_client)
         self.usecases = UsecasesAsyncModule(altscore_client)
         self.kpis = KpisAsyncModule(altscore_client)
         self.steps = StepsAsyncModule(altscore_client)
         self.list_of_similar = ListOfSimilarAsyncModule(altscore_client)
         self.execution_batches = ExecutionBatchAsyncModule(altscore_client)
         self.cms_settings = CMSSettingsAsyncModule(altscore_client)
+        self.communications = CommunicationsAsyncModule(altscore_client)
+        self.conversational_channel_connectors = ChannelConnectorAsyncModule(altscore_client)
+        self.conversational_conversations = ConversationAsyncModule(altscore_client)
+        self.conversational_messages = MessageAsyncModule(altscore_client)
+        self.custom_reports = CustomReportsSyncModule(altscore_client)
+        self.report_templates = ReportTemplateSyncModule(altscore_client)
+        self.deals = DealsAsyncModule(altscore_client)
+        self.deal_fields = DealFieldsAsyncModule(altscore_client)
+        self.deal_steps = DealStepsAsyncModule(altscore_client)
+        self.deal_contacts = DealContactsAsyncModule(altscore_client)
 
 
 class BorrowerCentralSync:
-
     def __init__(self, altscore_client):
         self.addresses = AddressesSyncModule(altscore_client)
         self.authorizations = AuthorizationsSyncModule(altscore_client)
@@ -101,9 +122,20 @@ class BorrowerCentralSync:
         self.rules = RulesSyncModule(altscore_client)
         self.policies = PolicySyncModule(altscore_client)
         self.sat_integration = SatIntegrationSyncModule(altscore_client)
+        self.sri_integration = SriIntegrationSyncModule(altscore_client)
         self.usecases = UsecasesSyncModule(altscore_client)
         self.kpis = KpisSyncModule(altscore_client)
         self.steps = StepsSyncModule(altscore_client)
         self.list_of_similar = ListOfSimilarSyncModule(altscore_client)
         self.execution_batches = ExecutionBatchSyncModule(altscore_client)
         self.cms_settings = CMSSettingsSyncModule(altscore_client)
+        self.communications = CommunicationsSyncModule(altscore_client)
+        self.conversational_channel_connectors = ChannelConnectorSyncModule(altscore_client)
+        self.conversational_conversations = ConversationSyncModule(altscore_client)
+        self.conversational_messages = MessageSyncModule(altscore_client)
+        self.custom_reports = CustomReportsSyncModule(altscore_client)
+        self.report_templates = ReportTemplateSyncModule(altscore_client)
+        self.deals = DealsSyncModule(altscore_client)
+        self.deal_fields = DealFieldsSyncModule(altscore_client)
+        self.deal_steps = DealStepsSyncModule(altscore_client)
+        self.deal_contacts = DealContactsSyncModule(altscore_client)
