@@ -2,6 +2,7 @@ from pydantic import BaseModel, Field
 from typing import Optional, List, Literal, Dict
 import httpx
 import asyncio
+import datetime as dt
 
 from altscore.borrower_central.helpers import build_headers
 from altscore.borrower_central.model.identities import IdentitySync, IdentityAsync
@@ -142,6 +143,21 @@ class CreateBorrowerDTO(BaseModel):
         allow_population_by_field_name = True
         populate_by_alias = True
 
+class SetRiskRatingAPIDTO(BaseModel):
+    value: str = Field(alias="value")
+    reference_id: Optional[str] = Field(alias="referenceId", default=None)
+    updated_at: Optional[dt.datetime] = Field(alias="updatedAt", default=None)
+
+    class Config:
+        populate_by_name = True
+        allow_population_by_field_name = True
+        allow_population_by_alias = True
+
+    def dict(self, *args, **kwargs):
+        base_dict = super().dict(*args, **kwargs)
+        date_key = 'updatedAt' if kwargs.get("by_alias") else 'updated_at'
+        base_dict[date_key] = self.updated_at.isoformat() if self.updated_at else None
+        return base_dict
 
 class UpdateBorrowerDTO(BaseModel):
     label: Optional[str] = Field(alias="label", default=None)
@@ -904,15 +920,16 @@ class BorrowerAsync(BorrowerBase):
             )
 
     @retry_on_401_async
-    async def set_risk_rating(self, risk_rating: str, reference_id: Optional[str] = None):
+    async def set_risk_rating(self, risk_rating: str, reference_id: Optional[str] = None, updated_at: Optional[dt.datetime] = None):
         async with httpx.AsyncClient(base_url=self.base_url) as client:
             response = await client.put(
                 f"{self.base_url}/v1/borrowers/{self.data.id}/risk-rating",
                 headers=self._header_builder(),
-                json={
+                json=SetRiskRatingAPIDTO.parse_obj({
                     "value": risk_rating,
-                    "referenceId": reference_id
-                }
+                    "reference_id": reference_id,
+                    "updated_at": updated_at
+                }).dict(by_alias=True)
             )
             raise_for_status_improved(response)
             return None
@@ -1019,6 +1036,26 @@ class BorrowerAsync(BorrowerBase):
                 data=data[0]
             )
 
+    @retry_on_401_async
+    async def get_document_by_key(self, key: str) -> Optional[DocumentAsync]:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            url, query = self._documents(self.data.id, key=key)
+            response = await client.get(
+                url,
+                headers=self._header_builder(),
+                params=query
+            )
+            data = response.json()
+            if len(data) == 0:
+                return None
+            return DocumentAsync(
+                base_url=self.base_url,
+                header_builder=self._header_builder,
+                renew_token=self.renew_token,
+                data=data[0]
+            )
+
+
     @retry_on_401_async
     async def get_identities(self, **kwargs) -> List[IdentityAsync]:
         async with httpx.AsyncClient(base_url=self.base_url) as client:
@@ -1405,15 +1442,16 @@ class BorrowerSync(BorrowerBase):
             )
 
     @retry_on_401
-    def set_risk_rating(self, risk_rating: str, reference_id: Optional[str] = None):
+    def set_risk_rating(self, risk_rating: str, reference_id: Optional[str] = None, updated_at: Optional[dt.datetime] = None):
         with httpx.Client(base_url=self.base_url) as client:
             response = client.put(
                 f"{self.base_url}/v1/borrowers/{self.data.id}/risk-rating",
                 headers=self._header_builder(),
-                json={
+                json=SetRiskRatingAPIDTO.parse_obj({
                     "value": risk_rating,
-                    "referenceId": reference_id
-                }
+                    "reference_id": reference_id,
+                    "updated_at": updated_at
+                }).dict(by_alias=True)
             )
             raise_for_status_improved(response)
             return None
@@ -1520,6 +1558,26 @@ class BorrowerSync(BorrowerBase):
                 data=data[0]
             )
 
+    @retry_on_401
+    def get_document_by_key(self, key) -> Optional[DocumentSync]:
+        with httpx.Client(base_url=self.base_url) as client:
+            url, query = self._documents(self.data.id, key=key)
+            response = client.get(
+                url,
+                headers=self._header_builder(),
+                params=query
+            )
+            data = response.json()
+            if len(data) == 0:
+                return None
+            return DocumentSync(
+                base_url=self.base_url,
+                header_builder=self._header_builder,
+                renew_token=self.renew_token,
+                data=data[0]
+            )
+
+
     @retry_on_401
     def get_identities(self, **kwargs) -> List[IdentitySync]:
         with httpx.Client(base_url=self.base_url) as client:
