@@ -3,7 +3,7 @@ import asyncio
 from pydantic import BaseModel, Field
 from typing import Optional, List
 import httpx
-
+from altscore.cms.model.calendars import CreateCalendarAPIDTO, DPACalendarAPIDTO
 from altscore.cms.model.dpa_segmentation import DPASegmentationAPIDTO, CreateDPASegmentationDTO, \
     UpdateDPASegmentationDTO
 from altscore.common.http_errors import raise_for_status_improved, retry_on_401, retry_on_401_async
@@ -11,6 +11,8 @@ from altscore.cms.model.generics import GenericSyncModule, GenericAsyncModule
 from altscore.cms.helpers import build_headers
 from altscore.cms.model.dpa_products import DPAProductAPIDTO, CreateDPAProductAPIDTO, UpdateDPAProductAPIDTO
 from altscore.borrower_central.utils import clean_dict, convert_to_dash_case
+from altscore.cms.model.disbursement_accounts import  BankAccount, DisbursementAccountBaseModel, CreateDisbursementPartnerAccountDTO
+from altscore.cms.model.credit_accounts import CreditAccountSync, CreditAccountAPIDTO
 
 
 class PartnerAPIDTO(BaseModel):
@@ -20,6 +22,7 @@ class PartnerAPIDTO(BaseModel):
     short_name: str = Field(alias="shortName")
     partner_id: str = Field(alias="partnerId")
     status: str = Field(alias="status")
+    tax_id: str = Field(alias="taxId")
     is_aggregator: bool = Field(alias="isAggregator")
     email: str = Field(alias="email")
     created_at: str = Field(alias="createdAt")
@@ -51,6 +54,7 @@ class DPASettingsDefaults(BaseModel):
     closing_balance_threshold: Optional[str] = Field(alias="closingBalanceThreshold", default=None)
     product_id: Optional[str] = Field(alias="productId", default=None)
     segmentation_id: Optional[str] = Field(alias="segmentationId", default=None)
+    calendar_type: Optional[str] = Field(alias="calendarType", default=None)
 
     class Config:
         populate_by_name = True
@@ -109,6 +113,12 @@ class PartnerBase:
         }
         return f"{self.base_url}/v2/partners/{partner_id}/segmentations/dpa", clean_dict(query)
 
+    def _get_partner_dpa_calendar (self, partner_id:str) -> (str, dict):
+        return f"{self.base_url}/v2/partners/{partner_id}/calendar/dpa", {}
+    
+    @staticmethod
+    def _create_disbursement_account(country: str):
+        return f"/v1/disbursements/accounts/{country}/disbursement"
 
 class PartnerAsync(PartnerBase):
     data: PartnerAPIDTO
@@ -270,6 +280,71 @@ class PartnerAsync(PartnerBase):
             )
             raise_for_status_improved(response)
 
+    @retry_on_401_async
+    async def get_dpa_calendars(self) -> List[DPACalendarAPIDTO]:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.get(
+                f"{self.base_url}/v2/partners/{self.data.partner_id}/calendars/dpa",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [DPACalendarAPIDTO.parse_obj(e) for e in response.json()]
+
+    @retry_on_401_async
+    async def get_dpa_calendar(self, calendar_id: str) -> Optional[DPACalendarAPIDTO]:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.get(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa/{calendar_id}",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            if response.status_code == 404:
+                return None
+            elif response.status_code == 200:
+                return DPACalendarAPIDTO.parse_obj(response.json())
+            raise_for_status_improved(response)
+
+    @retry_on_401_async
+    async def create_dpa_calendar(self, new_entity_data:dict) -> str:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.post(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa",
+                json=CreateCalendarAPIDTO.parse_obj(new_entity_data).dict(by_alias=True, exclude_none=True),
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return response.json()["calendarId"]
+
+
+    @retry_on_401_async
+    async def delete_dpa_calendar(self, calendar_id:str) -> None:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.delete(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa/{calendar_id}",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+
+    @retry_on_401_async
+    async def create_disbursement_account(self, country: str, bank_account: dict) -> DisbursementAccountBaseModel:
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.post(
+                self._create_disbursement_account(country),
+                headers=self._header_builder(partner_id=self.data.partner_id),
+                json=CreateDisbursementPartnerAccountDTO.parse_obj({
+                    "id": self.data.partner_id,
+                    "partnerId": self.data.partner_id,
+                    "bankAccount": BankAccount.parse_obj(bank_account).dict(by_alias=True, exclude_none=True),
+                    "taxId": self.data.tax_id,
+                    "name": self.data.name,
+                }).dict(by_alias=True, exclude_none=True),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return DisbursementAccountBaseModel.parse_obj(response.json())
 
 
 class PartnerSync(PartnerBase):
@@ -431,6 +506,71 @@ class PartnerSync(PartnerBase):
             )
             raise_for_status_improved(response)
 
+    @retry_on_401
+    def get_dpa_calendars(self) -> List[DPACalendarAPIDTO]:
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.get(
+                f"{self.base_url}/v2/partners/{self.data.partner_id}/calendars/dpa",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [DPACalendarAPIDTO.parse_obj(e) for e in response.json()]
+
+    @retry_on_401
+    def get_dpa_calendar(self, calendar_id: str) -> Optional[DPACalendarAPIDTO]:
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.get(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa/{calendar_id}",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            if response.status_code == 404:
+                return None
+            elif response.status_code == 200:
+                return DPACalendarAPIDTO.parse_obj(response.json())
+            raise_for_status_improved(response)
+
+    @retry_on_401
+    def create_dpa_calendar(self, new_entity_data: dict) -> str:
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.post(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa",
+                json=CreateCalendarAPIDTO.parse_obj(new_entity_data).dict(by_alias=True, exclude_none=True),
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return response.json()["calendarId"]
+
+    @retry_on_401
+    def delete_dpa_calendar(self, calendar_id: str) -> None:
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.delete(
+                f"/v2/partners/{self.data.partner_id}/calendars/dpa/{calendar_id}",
+                headers=self._header_builder(),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+    
+    @retry_on_401
+    def create_disbursement_account(self, country: str, bank_account: dict) -> DisbursementAccountBaseModel:
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.post(
+                self._create_disbursement_account(country),
+                headers=self._header_builder(partner_id=self.data.partner_id),
+                json=CreateDisbursementPartnerAccountDTO.parse_obj({
+                    "id": self.data.partner_id,
+                    "partnerId": self.data.partner_id,
+                    "bankAccount": BankAccount.parse_obj(bank_account).dict(by_alias=True, exclude_none=True),
+                    "taxId": self.data.tax_id,
+                    "name": self.data.name,
+                }).dict(by_alias=True, exclude_none=True),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return DisbursementAccountBaseModel.parse_obj(response.json())
+
 
 class PartnersAsyncModule(GenericAsyncModule):
 
@@ -485,6 +625,24 @@ class PartnersAsyncModule(GenericAsyncModule):
             )
             raise_for_status_improved(response)
             return DPASettingsAPIDTO.parse_obj(response.json())
+    
+    @retry_on_401
+    async def get_credit_accounts(self, product_family: str, **kwargs) -> CreditAccountSync:
+        query_params = {}
+        for k, v in kwargs.items():
+            if v is not None:
+                query_params[convert_to_dash_case(k)] = v
+
+        async with httpx.Client(base_url=self.altscore_client._cms_base_url) as client:
+            response = await client.get(
+                f"/v2/clients/credit-accounts/{product_family}",
+                params=query_params,
+                headers=build_headers(self),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [CreditAccountAPIDTO.parse_obj(item) for item in response.json()]
+
 
 
 class PartnersSyncModule(GenericSyncModule):
@@ -541,4 +699,19 @@ class PartnersSyncModule(GenericSyncModule):
             raise_for_status_improved(response)
             return DPASettingsAPIDTO.parse_obj(response.json())
 
+    @retry_on_401
+    def get_credit_accounts(self, product_family: str, **kwargs) -> CreditAccountSync:
+        query_params = {}
+        for k, v in kwargs.items():
+            if v is not None:
+                query_params[convert_to_dash_case(k)] = v
 
+        with httpx.Client(base_url=self.altscore_client._cms_base_url) as client:
+            response = client.get(
+                f"/v2/clients/credit-accounts/{product_family}",
+                params=query_params,
+                headers=build_headers(self),
+                timeout=30
+            )
+            raise_for_status_improved(response)
+            return [CreditAccountAPIDTO.parse_obj(item) for item in response.json()]
